Class: Google::Apis::AndroidenterpriseV1::DeviceState
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::DeviceState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
The state of a user's device, as accessed by the getState and setState methods on device resources.
Instance Attribute Summary collapse
-
#account_state ⇒ String
The state of the Google account on the device.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceState
constructor
A new instance of DeviceState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceState
Returns a new instance of DeviceState.
830 831 832 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_state ⇒ String
The state of the Google account on the device. "enabled" indicates that the
Google account on the device can be used to access Google services (including
Google Play), while "disabled" means that it cannot. A new device is initially
in the "disabled" state.
Corresponds to the JSON property accountState
828 829 830 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 828 def account_state @account_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
835 836 837 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 835 def update!(**args) @account_state = args[:account_state] if args.key?(:account_state) end |