Class: Google::Apis::AndroidenterpriseV1::Install
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::Install
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
The existence of an Installs resource indicates that an app is installed on a particular device (or that an install is pending). The API can be used to create an install resource using the update method. This triggers the actual install of the app on the device. If the user does not already have an entitlement for the app, then an attempt is made to create one. If this fails ( for example, because the app is not free and there is no available license), then the creation of the install fails. The API can also be used to update an installed app. If the update method is used on an existing install, then the app will be updated to the latest available version. Note that it is not possible to force the installation of a specific version of an app: the version code is read-only. If a user installs an app themselves (as permitted by the enterprise), then again an install resource and possibly an entitlement resource are automatically created. The API can also be used to delete an install resource, which triggers the removal of the app from the device. Note that deleting an install does not automatically remove the corresponding entitlement, even if there are no remaining installs. The install resource will also be deleted if the user uninstalls the app themselves.
Instance Attribute Summary collapse
-
#install_state ⇒ String
Install state.
-
#product_id ⇒ String
The ID of the product that the install is for.
-
#version_code ⇒ Fixnum
The version of the installed product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Install
constructor
A new instance of Install.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Install
Returns a new instance of Install.
1343 1344 1345 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#install_state ⇒ String
Install state. The state "installPending" means that an install request has
recently been made and download to the device is in progress. The state "
installed" means that the app has been installed. This field is read-only.
Corresponds to the JSON property installState
1329 1330 1331 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1329 def install_state @install_state end |
#product_id ⇒ String
The ID of the product that the install is for. For example, "app:com.google.
android.gm".
Corresponds to the JSON property productId
1335 1336 1337 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1335 def product_id @product_id end |
#version_code ⇒ Fixnum
The version of the installed product. Guaranteed to be set only if the install
state is "installed".
Corresponds to the JSON property versionCode
1341 1342 1343 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1341 def version_code @version_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1348 1349 1350 1351 1352 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1348 def update!(**args) @install_state = args[:install_state] if args.key?(:install_state) @product_id = args[:product_id] if args.key?(:product_id) @version_code = args[:version_code] if args.key?(:version_code) end |