Class: Google::Apis::AndroidenterpriseV1::MaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

Maintenance window for managed Google Play Accounts. This allows Play store to update the apps on the foreground in the designated window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceWindow

Returns a new instance of MaintenanceWindow.



1512
1513
1514
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#duration_msFixnum

Duration of the maintenance window, in milliseconds. The duration must be between 30 minutes and 24 hours (inclusive). Corresponds to the JSON property durationMs

Returns:

  • (Fixnum)


1504
1505
1506
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1504

def duration_ms
  @duration_ms
end

#start_time_after_midnight_msFixnum

Start time of the maintenance window, in milliseconds after midnight on the device. Windows can span midnight. Corresponds to the JSON property startTimeAfterMidnightMs

Returns:

  • (Fixnum)


1510
1511
1512
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1510

def start_time_after_midnight_ms
  @start_time_after_midnight_ms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1517
1518
1519
1520
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1517

def update!(**args)
  @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
  @start_time_after_midnight_ms = args[:start_time_after_midnight_ms] if args.key?(:start_time_after_midnight_ms)
end