Class: Google::Apis::AndroidenterpriseV1::ManagedConfigurationsForDeviceListResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::ManagedConfigurationsForDeviceListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Instance Attribute Summary collapse
-
#managed_configuration_for_device ⇒ Array<Google::Apis::AndroidenterpriseV1::ManagedConfiguration>
A managed configuration for an app on a specific device.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedConfigurationsForDeviceListResponse
constructor
A new instance of ManagedConfigurationsForDeviceListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedConfigurationsForDeviceListResponse
Returns a new instance of ManagedConfigurationsForDeviceListResponse.
1574 1575 1576 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#managed_configuration_for_device ⇒ Array<Google::Apis::AndroidenterpriseV1::ManagedConfiguration>
A managed configuration for an app on a specific device.
Corresponds to the JSON property managedConfigurationForDevice
1572 1573 1574 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1572 def managed_configuration_for_device @managed_configuration_for_device end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1579 1580 1581 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1579 def update!(**args) @managed_configuration_for_device = args[:managed_configuration_for_device] if args.key?(:managed_configuration_for_device) end |