Class: Google::Apis::AndroidenterpriseV1::ManagedProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

A managed property of a managed configuration. The property must match one of the properties in the app restrictions schema of the product. Exactly one of the value fields must be populated, and it must match the property's type in the app restrictions schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedProperty

Returns a new instance of ManagedProperty.



1699
1700
1701
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

The unique key that identifies the property. Corresponds to the JSON property key

Returns:

  • (String)


1662
1663
1664
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1662

def key
  @key
end

#value_boolBoolean Also known as: value_bool?

The boolean value - this will only be present if type of the property is bool. Corresponds to the JSON property valueBool

Returns:

  • (Boolean)


1667
1668
1669
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1667

def value_bool
  @value_bool
end

#value_bundleGoogle::Apis::AndroidenterpriseV1::ManagedPropertyBundle

A bundle of managed properties. Corresponds to the JSON property valueBundle



1673
1674
1675
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1673

def value_bundle
  @value_bundle
end

#value_bundle_arrayArray<Google::Apis::AndroidenterpriseV1::ManagedPropertyBundle>

The list of bundles of properties - this will only be present if type of the property is bundle_array. Corresponds to the JSON property valueBundleArray



1679
1680
1681
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1679

def value_bundle_array
  @value_bundle_array
end

#value_integerFixnum

The integer value - this will only be present if type of the property is integer. Corresponds to the JSON property valueInteger

Returns:

  • (Fixnum)


1685
1686
1687
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1685

def value_integer
  @value_integer
end

#value_stringString

The string value - this will only be present if type of the property is string, choice or hidden. Corresponds to the JSON property valueString

Returns:

  • (String)


1691
1692
1693
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1691

def value_string
  @value_string
end

#value_string_arrayArray<String>

The list of string values - this will only be present if type of the property is multiselect. Corresponds to the JSON property valueStringArray

Returns:

  • (Array<String>)


1697
1698
1699
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1697

def value_string_array
  @value_string_array
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1704
1705
1706
1707
1708
1709
1710
1711
1712
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1704

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value_bool = args[:value_bool] if args.key?(:value_bool)
  @value_bundle = args[:value_bundle] if args.key?(:value_bundle)
  @value_bundle_array = args[:value_bundle_array] if args.key?(:value_bundle_array)
  @value_integer = args[:value_integer] if args.key?(:value_integer)
  @value_string = args[:value_string] if args.key?(:value_string)
  @value_string_array = args[:value_string_array] if args.key?(:value_string_array)
end