Class: Google::Apis::AndroidenterpriseV1::NewDeviceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

An event generated when a new device is ready to be managed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NewDeviceEvent

Returns a new instance of NewDeviceEvent.



1767
1768
1769
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_idString

The Android ID of the device. This field will always be present. Corresponds to the JSON property deviceId

Returns:

  • (String)


1747
1748
1749
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1747

def device_id
  @device_id
end

#dpc_package_nameString

Policy app on the device. Corresponds to the JSON property dpcPackageName

Returns:

  • (String)


1752
1753
1754
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1752

def dpc_package_name
  @dpc_package_name
end

#management_typeString

Identifies the extent to which the device is controlled by an Android EMM in various deployment configurations. Possible values include: - "managedDevice", a device where the DPC is set as device owner, - "managedProfile", a device where the DPC is set as profile owner. Corresponds to the JSON property managementType

Returns:

  • (String)


1760
1761
1762
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1760

def management_type
  @management_type
end

#user_idString

The ID of the user. This field will always be present. Corresponds to the JSON property userId

Returns:

  • (String)


1765
1766
1767
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1765

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1772
1773
1774
1775
1776
1777
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1772

def update!(**args)
  @device_id = args[:device_id] if args.key?(:device_id)
  @dpc_package_name = args[:dpc_package_name] if args.key?(:dpc_package_name)
  @management_type = args[:management_type] if args.key?(:management_type)
  @user_id = args[:user_id] if args.key?(:user_id)
end