Class: Google::Apis::AndroidenterpriseV1::NotificationSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

A resource returned by the PullNotificationSet API, which contains a collection of notifications for enterprises associated with the service account authenticated for the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationSet

Returns a new instance of NotificationSet.



1919
1920
1921
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#notificationArray<Google::Apis::AndroidenterpriseV1::Notification>

The notifications received, or empty if no notifications are present. Corresponds to the JSON property notification



1910
1911
1912
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1910

def notification
  @notification
end

#notification_set_idString

The notification set ID, required to mark the notification as received with the Enterprises.AcknowledgeNotification API. This will be omitted if no notifications are present. Corresponds to the JSON property notificationSetId

Returns:

  • (String)


1917
1918
1919
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1917

def notification_set_id
  @notification_set_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1924
1925
1926
1927
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1924

def update!(**args)
  @notification = args[:notification] if args.key?(:notification)
  @notification_set_id = args[:notification_set_id] if args.key?(:notification_set_id)
end