Class: Google::Apis::AndroidenterpriseV1::PageInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::PageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Information about the current page. List operations that supports paging return only one "page" of results. This protocol buffer message describes the page that has been returned.
Instance Attribute Summary collapse
-
#result_per_page ⇒ Fixnum
Maximum number of results returned in one page.
-
#start_index ⇒ Fixnum
Index of the first result returned in the current page.
-
#total_results ⇒ Fixnum
Total number of results available on the backend ! The total number of results in the result set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PageInfo
constructor
A new instance of PageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PageInfo
Returns a new instance of PageInfo.
1959 1960 1961 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#result_per_page ⇒ Fixnum
Maximum number of results returned in one page. ! The number of results
included in the API response.
Corresponds to the JSON property resultPerPage
1946 1947 1948 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1946 def result_per_page @result_per_page end |
#start_index ⇒ Fixnum
Index of the first result returned in the current page.
Corresponds to the JSON property startIndex
1951 1952 1953 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1951 def start_index @start_index end |
#total_results ⇒ Fixnum
Total number of results available on the backend ! The total number of results
in the result set.
Corresponds to the JSON property totalResults
1957 1958 1959 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1957 def total_results @total_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1964 1965 1966 1967 1968 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1964 def update!(**args) @result_per_page = args[:result_per_page] if args.key?(:result_per_page) @start_index = args[:start_index] if args.key?(:start_index) @total_results = args[:total_results] if args.key?(:total_results) end |