Class: Google::Apis::AndroidenterpriseV1::Policy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

The device policy for a given managed device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Policy

Returns a new instance of Policy.



2054
2055
2056
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_update_policyString

Controls when automatic app updates on the device can be applied. Recommended alternative: autoUpdateMode which is set per app, provides greater flexibility around update frequency. When autoUpdateMode is set to AUTO_UPDATE_POSTPONED or AUTO_UPDATE_HIGH_PRIORITY, autoUpdatePolicy has no effect. - choiceToTheUser allows the device's user to configure the app update policy. - always enables auto updates. - never disables auto updates. - wifiOnly enables auto updates only when the device is connected to wifi. Important: Changes to app update policies don't affect updates that are in progress. Any policy changes will apply to subsequent app updates. Corresponds to the JSON property autoUpdatePolicy

Returns:

  • (String)


2017
2018
2019
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2017

def auto_update_policy
  @auto_update_policy
end

#device_report_policyString

Whether the device reports app states to the EMM. The default value is " deviceReportDisabled". Corresponds to the JSON property deviceReportPolicy

Returns:

  • (String)


2023
2024
2025
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2023

def device_report_policy
  @device_report_policy
end

#maintenance_windowGoogle::Apis::AndroidenterpriseV1::MaintenanceWindow

Maintenance window for managed Google Play Accounts. This allows Play store to update the apps on the foreground in the designated window. Corresponds to the JSON property maintenanceWindow



2029
2030
2031
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2029

def maintenance_window
  @maintenance_window
end

#policy_idString

An identifier for the policy that will be passed with the app install feedback sent from the Play Store. Corresponds to the JSON property policyId

Returns:

  • (String)


2035
2036
2037
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2035

def policy_id
  @policy_id
end

#product_availability_policyString

The availability granted to the device for the specified products. "all" gives the device access to all products, regardless of approval status. "all" does not enable automatic visibility of "alpha" or "beta" tracks. "whitelist" grants the device access the products specified in productPolicy[]. Only products that are approved or products that were previously approved (products with revoked approval) by the enterprise can be whitelisted. If no value is provided, the availability set at the user level is applied by default. Corresponds to the JSON property productAvailabilityPolicy

Returns:

  • (String)


2046
2047
2048
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2046

def product_availability_policy
  @product_availability_policy
end

#product_policyArray<Google::Apis::AndroidenterpriseV1::ProductPolicy>

The list of product policies. The productAvailabilityPolicy needs to be set to WHITELIST or ALL for the product policies to be applied. Corresponds to the JSON property productPolicy



2052
2053
2054
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2052

def product_policy
  @product_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2059
2060
2061
2062
2063
2064
2065
2066
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2059

def update!(**args)
  @auto_update_policy = args[:auto_update_policy] if args.key?(:auto_update_policy)
  @device_report_policy = args[:device_report_policy] if args.key?(:device_report_policy)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @policy_id = args[:policy_id] if args.key?(:policy_id)
  @product_availability_policy = args[:product_availability_policy] if args.key?(:product_availability_policy)
  @product_policy = args[:product_policy] if args.key?(:product_policy)
end