Class: Google::Apis::AndroidenterpriseV1::ProductPermission

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

A product permissions resource represents the set of permissions required by a specific app and whether or not they have been accepted by an enterprise admin. The API can be used to read the set of permissions, and also to update the set to indicate that permissions have been accepted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductPermission

Returns a new instance of ProductPermission.



2327
2328
2329
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#permission_idString

An opaque string uniquely identifying the permission. Corresponds to the JSON property permissionId

Returns:

  • (String)


2320
2321
2322
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2320

def permission_id
  @permission_id
end

#stateString

Whether the permission has been accepted or not. Corresponds to the JSON property state

Returns:

  • (String)


2325
2326
2327
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2325

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2332
2333
2334
2335
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2332

def update!(**args)
  @permission_id = args[:permission_id] if args.key?(:permission_id)
  @state = args[:state] if args.key?(:state)
end