Class: Google::Apis::AndroidenterpriseV1::ProductSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

A set of products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductSet

Returns a new instance of ProductSet.



2467
2468
2469
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_idArray<String>

The list of product IDs making up the set of products. Corresponds to the JSON property productId

Returns:

  • (Array<String>)


2441
2442
2443
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2441

def product_id
  @product_id
end

#product_set_behaviorString

The interpretation of this product set. "unknown" should never be sent and is ignored if received. "whitelist" means that the user is entitled to access the product set. "includeAll" means that all products are accessible, including products that are approved, products with revoked approval, and products that have never been approved. "allApproved" means that the user is entitled to access all products that are approved for the enterprise. If the value is " allApproved" or "includeAll", the productId field is ignored. If no value is provided, it is interpreted as "whitelist" for backwards compatibility. Further "allApproved" or "includeAll" does not enable automatic visibility of " alpha" or "beta" tracks for Android app. Use ProductVisibility to enable " alpha" or "beta" tracks per user. Corresponds to the JSON property productSetBehavior

Returns:

  • (String)


2456
2457
2458
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2456

def product_set_behavior
  @product_set_behavior
end

#product_visibilityArray<Google::Apis::AndroidenterpriseV1::ProductVisibility>

Additional list of product IDs making up the product set. Unlike the productID array, in this list It's possible to specify which tracks (alpha, beta, production) of a product are visible to the user. See ProductVisibility and its fields for more information. Specifying the same product ID both here and in the productId array is not allowed and it will result in an error. Corresponds to the JSON property productVisibility



2465
2466
2467
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2465

def product_visibility
  @product_visibility
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2472
2473
2474
2475
2476
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2472

def update!(**args)
  @product_id = args[:product_id] if args.key?(:product_id)
  @product_set_behavior = args[:product_set_behavior] if args.key?(:product_set_behavior)
  @product_visibility = args[:product_visibility] if args.key?(:product_visibility)
end