Class: Google::Apis::AndroidenterpriseV1::ProductVisibility
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::ProductVisibility
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A product to be made visible to a user.
Instance Attribute Summary collapse
-
#product_id ⇒ String
The product ID to make visible to the user.
-
#track_ids ⇒ Array<String>
Grants the user visibility to the specified product track(s), identified by trackIds.
-
#tracks ⇒ Array<String>
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductVisibility
constructor
A new instance of ProductVisibility.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductVisibility
Returns a new instance of ProductVisibility.
2528 2529 2530 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2528 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_id ⇒ String
The product ID to make visible to the user. Required for each item in the
productVisibility list.
Corresponds to the JSON property productId
2515 2516 2517 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2515 def product_id @product_id end |
#track_ids ⇒ Array<String>
Grants the user visibility to the specified product track(s), identified by
trackIds.
Corresponds to the JSON property trackIds
2521 2522 2523 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2521 def track_ids @track_ids end |
#tracks ⇒ Array<String>
Deprecated. Use trackIds instead.
Corresponds to the JSON property tracks
2526 2527 2528 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2526 def tracks @tracks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2533 2534 2535 2536 2537 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2533 def update!(**args) @product_id = args[:product_id] if args.key?(:product_id) @track_ids = args[:track_ids] if args.key?(:track_ids) @tracks = args[:tracks] if args.key?(:tracks) end |