Class: Google::Apis::AndroidenterpriseV1::ServiceAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

A service account identity, including the name and credentials that can be used to authenticate as the service account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAccount

Returns a new instance of ServiceAccount.



2654
2655
2656
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyGoogle::Apis::AndroidenterpriseV1::ServiceAccountKey

Deprecated: New integrations cannot use this method and can refer to our new recommendations Corresponds to the JSON property key



2646
2647
2648
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2646

def key
  @key
end

#nameString

The account name of the service account, in the form of an email address. Assigned by the server. Corresponds to the JSON property name

Returns:

  • (String)


2652
2653
2654
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2652

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2659
2660
2661
2662
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2659

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @name = args[:name] if args.key?(:name)
end