Class: Google::Apis::AndroidenterpriseV1::StoreCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

Definition of a managed Google Play store cluster, a list of products displayed as part of a store page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoreCluster

Returns a new instance of StoreCluster.



2795
2796
2797
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique ID of this cluster. Assigned by the server. Immutable once assigned. Corresponds to the JSON property id

Returns:

  • (String)


2770
2771
2772
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2770

def id
  @id
end

#nameArray<Google::Apis::AndroidenterpriseV1::LocalizedText>

Ordered list of localized strings giving the name of this page. The text displayed is the one that best matches the user locale, or the first entry if there is no good match. There needs to be at least one entry. Corresponds to the JSON property name



2777
2778
2779
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2777

def name
  @name
end

#order_in_pageString

String (US-ASCII only) used to determine order of this cluster within the parent page's elements. Page elements are sorted in lexicographic order of this field. Duplicated values are allowed, but ordering between elements with duplicate order is undefined. The value of this field is never visible to a user, it is used solely for the purpose of defining an ordering. Maximum length is 256 characters. Corresponds to the JSON property orderInPage

Returns:

  • (String)


2787
2788
2789
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2787

def order_in_page
  @order_in_page
end

#product_idArray<String>

List of products in the order they are displayed in the cluster. There should not be duplicates within a cluster. Corresponds to the JSON property productId

Returns:

  • (Array<String>)


2793
2794
2795
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2793

def product_id
  @product_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2800
2801
2802
2803
2804
2805
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2800

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @order_in_page = args[:order_in_page] if args.key?(:order_in_page)
  @product_id = args[:product_id] if args.key?(:product_id)
end