Class: Google::Apis::AndroidenterpriseV1::StorePage
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::StorePage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Definition of a managed Google Play store page, made of a localized name and links to other pages. A page also contains clusters defined as a subcollection.
Instance Attribute Summary collapse
-
#id ⇒ String
Unique ID of this page.
-
#link ⇒ Array<String>
Ordered list of pages a user should be able to reach from this page.
-
#name ⇒ Array<Google::Apis::AndroidenterpriseV1::LocalizedText>
Ordered list of localized strings giving the name of this page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorePage
constructor
A new instance of StorePage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorePage
Returns a new instance of StorePage.
2896 2897 2898 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique ID of this page. Assigned by the server. Immutable once assigned.
Corresponds to the JSON property id
2879 2880 2881 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2879 def id @id end |
#link ⇒ Array<String>
Ordered list of pages a user should be able to reach from this page. The list
can't include this page. It is recommended that the basic pages are created
first, before adding the links between pages. The API doesn't verify that the
pages exist or the pages are reachable.
Corresponds to the JSON property link
2887 2888 2889 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2887 def link @link end |
#name ⇒ Array<Google::Apis::AndroidenterpriseV1::LocalizedText>
Ordered list of localized strings giving the name of this page. The text
displayed is the one that best matches the user locale, or the first entry if
there is no good match. There needs to be at least one entry.
Corresponds to the JSON property name
2894 2895 2896 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2894 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2901 2902 2903 2904 2905 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2901 def update!(**args) @id = args[:id] if args.key?(:id) @link = args[:link] if args.key?(:link) @name = args[:name] if args.key?(:name) end |