Class: Google::Apis::AndroidenterpriseV1::User
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A Users resource represents an account associated with an enterprise. The account may be specific to a device or to an individual user (who can then use the account across multiple devices). The account may provide access to managed Google Play only, or to other Google services, depending on the identity model: - The Google managed domain identity model requires synchronization to Google account sources (via primaryEmail). - The managed Google Play Accounts identity model provides a dynamic means for enterprises to create user or device accounts as needed. These accounts provide access to managed Google Play.
Instance Attribute Summary collapse
-
#account_identifier ⇒ String
A unique identifier you create for this user, such as "user342" or "asset# 44418".
-
#account_type ⇒ String
The type of account that this user represents.
-
#display_name ⇒ String
The name that will appear in user interfaces.
-
#id ⇒ String
The unique ID for the user.
-
#management_type ⇒ String
The entity that manages the user.
-
#primary_email ⇒ String
The user's primary email address, for example, "jsmith@example.com".
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
3023 3024 3025 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3023 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_identifier ⇒ String
A unique identifier you create for this user, such as "user342" or "asset#
44418". Do not use personally identifiable information (PII) for this property.
Must always be set for EMM-managed users. Not set for Google-managed users.
Corresponds to the JSON property accountIdentifier
2986 2987 2988 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2986 def account_identifier @account_identifier end |
#account_type ⇒ String
The type of account that this user represents. A userAccount can be installed
on multiple devices, but a deviceAccount is specific to a single device. An
EMM-managed user (emmManaged) can be either type (userAccount, deviceAccount),
but a Google-managed user (googleManaged) is always a userAccount.
Corresponds to the JSON property accountType
2994 2995 2996 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2994 def account_type @account_type end |
#display_name ⇒ String
The name that will appear in user interfaces. Setting this property is
optional when creating EMM-managed users. If you do set this property, use
something generic about the organization (such as "Example, Inc.") or your
name (as EMM). Not used for Google-managed user accounts. @mutable
androidenterprise.users.update
Corresponds to the JSON property displayName
3003 3004 3005 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3003 def display_name @display_name end |
#id ⇒ String
The unique ID for the user.
Corresponds to the JSON property id
3008 3009 3010 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3008 def id @id end |
#management_type ⇒ String
The entity that manages the user. With googleManaged users, the source of
truth is Google so EMMs have to make sure a Google Account exists for the user.
With emmManaged users, the EMM is in charge.
Corresponds to the JSON property managementType
3015 3016 3017 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3015 def management_type @management_type end |
#primary_email ⇒ String
The user's primary email address, for example, "jsmith@example.com". Will
always be set for Google managed users and not set for EMM managed users.
Corresponds to the JSON property primaryEmail
3021 3022 3023 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3021 def primary_email @primary_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3028 3029 3030 3031 3032 3033 3034 3035 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3028 def update!(**args) @account_identifier = args[:account_identifier] if args.key?(:account_identifier) @account_type = args[:account_type] if args.key?(:account_type) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @management_type = args[:management_type] if args.key?(:management_type) @primary_email = args[:primary_email] if args.key?(:primary_email) end |