Class: Google::Apis::AndroidenterpriseV1::WebApp
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::WebApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A WebApps resource represents a web app created for an enterprise. Web apps are published to managed Google Play and can be distributed like other Android apps. On a user's device, a web app opens its specified URL.
Instance Attribute Summary collapse
-
#display_mode ⇒ String
The display mode of the web app.
-
#icons ⇒ Array<Google::Apis::AndroidenterpriseV1::WebAppIcon>
A list of icons representing this website.
-
#is_published ⇒ Boolean
(also: #is_published?)
A flag whether the app has been published to the Play store yet.
-
#start_url ⇒ String
The start URL, i.e.
-
#title ⇒ String
The title of the web app as displayed to the user (e.g., amongst a list of other applications, or as a label for an icon).
-
#version_code ⇒ Fixnum
The current version of the app.
-
#web_app_id ⇒ String
The ID of the application.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WebApp
constructor
A new instance of WebApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WebApp
Returns a new instance of WebApp.
3146 3147 3148 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_mode ⇒ String
The display mode of the web app. Possible values include: - "minimalUi", the
device's status bar, navigation bar, the app's URL, and a refresh button are
visible when the app is open. For HTTP URLs, you can only select this option. -
"standalone", the device's status bar and navigation bar are visible when the
app is open. - "fullScreen", the app opens in full screen mode, hiding the
device's status and navigation bars. All browser UI elements, page URL, system
status bar and back button are not visible, and the web app takes up the
entirety of the available display area.
Corresponds to the JSON property displayMode
3106 3107 3108 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3106 def display_mode @display_mode end |
#icons ⇒ Array<Google::Apis::AndroidenterpriseV1::WebAppIcon>
A list of icons representing this website. If absent, a default icon (for
create) or the current icon (for update) will be used.
Corresponds to the JSON property icons
3112 3113 3114 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3112 def icons @icons end |
#is_published ⇒ Boolean Also known as: is_published?
A flag whether the app has been published to the Play store yet.
Corresponds to the JSON property isPublished
3117 3118 3119 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3117 def is_published @is_published end |
#start_url ⇒ String
The start URL, i.e. the URL that should load when the user opens the
application.
Corresponds to the JSON property startUrl
3124 3125 3126 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3124 def start_url @start_url end |
#title ⇒ String
The title of the web app as displayed to the user (e.g., amongst a list of
other applications, or as a label for an icon).
Corresponds to the JSON property title
3130 3131 3132 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3130 def title @title end |
#version_code ⇒ Fixnum
The current version of the app. Note that the version can automatically
increase during the lifetime of the web app, while Google does internal
housekeeping to keep the web app up-to-date.
Corresponds to the JSON property versionCode
3137 3138 3139 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3137 def version_code @version_code end |
#web_app_id ⇒ String
The ID of the application. A string of the form "app:webAppId
3144 3145 3146 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3144 def web_app_id @web_app_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3151 3152 3153 3154 3155 3156 3157 3158 3159 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 3151 def update!(**args) @display_mode = args[:display_mode] if args.key?(:display_mode) @icons = args[:icons] if args.key?(:icons) @is_published = args[:is_published] if args.key?(:is_published) @start_url = args[:start_url] if args.key?(:start_url) @title = args[:title] if args.key?(:title) @version_code = args[:version_code] if args.key?(:version_code) @web_app_id = args[:web_app_id] if args.key?(:web_app_id) end |