Class: Google::Apis::AndroidenterpriseV1::ApproveProductRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::ApproveProductRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Instance Attribute Summary collapse
-
#approval_url_info ⇒ Google::Apis::AndroidenterpriseV1::ApprovalUrlInfo
Information on an approval URL.
-
#approved_permissions ⇒ String
Sets how new permission requests for the product are handled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApproveProductRequest
constructor
A new instance of ApproveProductRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApproveProductRequest
Returns a new instance of ApproveProductRequest.
2553 2554 2555 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_url_info ⇒ Google::Apis::AndroidenterpriseV1::ApprovalUrlInfo
Information on an approval URL.
Corresponds to the JSON property approvalUrlInfo
2541 2542 2543 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2541 def approval_url_info @approval_url_info end |
#approved_permissions ⇒ String
Sets how new permission requests for the product are handled. "allPermissions"
automatically approves all current and future permissions for the product. "
currentPermissionsOnly" approves the current set of permissions for the
product, but any future permissions added through updates will require manual
reapproval. If not specified, only the current set of permissions will be
approved.
Corresponds to the JSON property approvedPermissions
2551 2552 2553 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2551 def @approved_permissions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2558 2559 2560 2561 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2558 def update!(**args) @approval_url_info = args[:approval_url_info] if args.key?(:approval_url_info) @approved_permissions = args[:approved_permissions] if args.key?(:approved_permissions) end |