Class: Google::Apis::AndroidenterpriseV1::ApproveProductRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApproveProductRequest

Returns a new instance of ApproveProductRequest.



2558
2559
2560
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_url_infoGoogle::Apis::AndroidenterpriseV1::ApprovalUrlInfo

Information on an approval URL. Corresponds to the JSON property approvalUrlInfo



2546
2547
2548
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2546

def approval_url_info
  @approval_url_info
end

#approved_permissionsString

Sets how new permission requests for the product are handled. "allPermissions" automatically approves all current and future permissions for the product. " currentPermissionsOnly" approves the current set of permissions for the product, but any future permissions added through updates will require manual reapproval. If not specified, only the current set of permissions will be approved. Corresponds to the JSON property approvedPermissions

Returns:

  • (String)


2556
2557
2558
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2556

def approved_permissions
  @approved_permissions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2563
2564
2565
2566
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2563

def update!(**args)
  @approval_url_info = args[:approval_url_info] if args.key?(:approval_url_info)
  @approved_permissions = args[:approved_permissions] if args.key?(:approved_permissions)
end