Class: Google::Apis::AndroidenterpriseV1::DeviceReport
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::DeviceReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Device report updated with the latest app states for managed apps on the device.
Instance Attribute Summary collapse
-
#app_state ⇒ Array<Google::Apis::AndroidenterpriseV1::AppState>
List of app states set by managed apps on the device.
-
#last_updated_timestamp_millis ⇒ Fixnum
The timestamp of the last report update in milliseconds since epoch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceReport
constructor
A new instance of DeviceReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceReport
Returns a new instance of DeviceReport.
774 775 776 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_state ⇒ Array<Google::Apis::AndroidenterpriseV1::AppState>
List of app states set by managed apps on the device. App states are defined
by the app's developers. This field will always be present.
Corresponds to the JSON property appState
766 767 768 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 766 def app_state @app_state end |
#last_updated_timestamp_millis ⇒ Fixnum
The timestamp of the last report update in milliseconds since epoch. This
field will always be present.
Corresponds to the JSON property lastUpdatedTimestampMillis
772 773 774 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 772 def @last_updated_timestamp_millis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
779 780 781 782 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 779 def update!(**args) @app_state = args[:app_state] if args.key?(:app_state) @last_updated_timestamp_millis = args[:last_updated_timestamp_millis] if args.key?(:last_updated_timestamp_millis) end |