Class: Google::Apis::AndroidenterpriseV1::EnrollmentToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

A token used to enroll a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnrollmentToken

Returns a new instance of EnrollmentToken.



887
888
889
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

[Optional] The length of time the enrollment token is valid, ranging from 1 minute to Durations.MAX_VALUE, approximately 10,000 years. If not specified, the default duration is 1 hour. Corresponds to the JSON property duration

Returns:

  • (String)


869
870
871
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 869

def duration
  @duration
end

#enrollment_token_typeString

[Required] The type of the enrollment token. Corresponds to the JSON property enrollmentTokenType

Returns:

  • (String)


874
875
876
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 874

def enrollment_token_type
  @enrollment_token_type
end

#google_authentication_optionsGoogle::Apis::AndroidenterpriseV1::EnrollmentTokenGoogleAuthenticationOptions

Options for Google authentication during the enrollment. Corresponds to the JSON property googleAuthenticationOptions



879
880
881
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 879

def google_authentication_options
  @google_authentication_options
end

#tokenString

The token value that's passed to the device and authorizes the device to enroll. This is a read-only field generated by the server. Corresponds to the JSON property token

Returns:

  • (String)


885
886
887
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 885

def token
  @token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



892
893
894
895
896
897
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 892

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @enrollment_token_type = args[:enrollment_token_type] if args.key?(:enrollment_token_type)
  @google_authentication_options = args[:google_authentication_options] if args.key?(:google_authentication_options)
  @token = args[:token] if args.key?(:token)
end