Class: Google::Apis::AndroidenterpriseV1::EnrollmentTokenGoogleAuthenticationOptions
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::EnrollmentTokenGoogleAuthenticationOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Options for Google authentication during the enrollment.
Instance Attribute Summary collapse
-
#authentication_requirement ⇒ String
[Optional] Specifies whether user should authenticate with Google during enrollment.
-
#required_account_email ⇒ String
[Optional] Specifies the managed Google account that the user must use during enrollment.
AuthenticationRequirementmust be set toREQUIREDif this field is set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnrollmentTokenGoogleAuthenticationOptions
constructor
A new instance of EnrollmentTokenGoogleAuthenticationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnrollmentTokenGoogleAuthenticationOptions
Returns a new instance of EnrollmentTokenGoogleAuthenticationOptions.
920 921 922 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_requirement ⇒ String
[Optional] Specifies whether user should authenticate with Google during
enrollment. This setting, if specified,GoogleAuthenticationSettings
specified for the enterprise resource is ignored for devices enrolled with
this token.
Corresponds to the JSON property authenticationRequirement
911 912 913 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 911 def authentication_requirement @authentication_requirement end |
#required_account_email ⇒ String
[Optional] Specifies the managed Google account that the user must use during
enrollment.AuthenticationRequirement must be set toREQUIRED if this field
is set.
Corresponds to the JSON property requiredAccountEmail
918 919 920 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 918 def required_account_email @required_account_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
925 926 927 928 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 925 def update!(**args) @authentication_requirement = args[:authentication_requirement] if args.key?(:authentication_requirement) @required_account_email = args[:required_account_email] if args.key?(:required_account_email) end |