Class: Google::Apis::AndroidenterpriseV1::Enterprise
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::Enterprise
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
An Enterprises resource represents the binding between an EMM and a specific organization. That binding can be instantiated in one of two different ways using this API as follows: - For Google managed domain customers, the process involves using Enterprises.enroll and Enterprises.setAccount (in conjunction with artifacts obtained from the Admin console and the Google API Console) and submitted to the EMM through a more-or-less manual process. - For managed Google Play Accounts customers, the process involves using Enterprises. generateSignupUrl and Enterprises.completeSignup in conjunction with the managed Google Play sign-up UI (Google-provided mechanism) to create the binding without manual steps. As an EMM, you can support either or both approaches in your EMM console. See Create an Enterprise for details.
Instance Attribute Summary collapse
-
#administrator ⇒ Array<Google::Apis::AndroidenterpriseV1::Administrator>
Admins of the enterprise.
-
#enterprise_type ⇒ String
The type of the enterprise.
-
#google_authentication_settings ⇒ Google::Apis::AndroidenterpriseV1::GoogleAuthenticationSettings
Contains settings for Google-provided user authentication.
-
#id ⇒ String
The unique ID for the enterprise.
-
#managed_google_domain_type ⇒ String
The type of managed Google domain Corresponds to the JSON property
managedGoogleDomainType. -
#name ⇒ String
The name of the enterprise, for example, "Example, Inc".
-
#primary_domain ⇒ String
The enterprise's primary domain, such as "example.com".
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enterprise
constructor
A new instance of Enterprise.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enterprise
Returns a new instance of Enterprise.
981 982 983 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#administrator ⇒ Array<Google::Apis::AndroidenterpriseV1::Administrator>
Admins of the enterprise. This is only supported for enterprises created via
the EMM-initiated flow.
Corresponds to the JSON property administrator
949 950 951 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 949 def administrator @administrator end |
#enterprise_type ⇒ String
The type of the enterprise.
Corresponds to the JSON property enterpriseType
954 955 956 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 954 def enterprise_type @enterprise_type end |
#google_authentication_settings ⇒ Google::Apis::AndroidenterpriseV1::GoogleAuthenticationSettings
Contains settings for Google-provided user authentication.
Corresponds to the JSON property googleAuthenticationSettings
959 960 961 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 959 def google_authentication_settings @google_authentication_settings end |
#id ⇒ String
The unique ID for the enterprise.
Corresponds to the JSON property id
964 965 966 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 964 def id @id end |
#managed_google_domain_type ⇒ String
The type of managed Google domain
Corresponds to the JSON property managedGoogleDomainType
969 970 971 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 969 def managed_google_domain_type @managed_google_domain_type end |
#name ⇒ String
The name of the enterprise, for example, "Example, Inc".
Corresponds to the JSON property name
974 975 976 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 974 def name @name end |
#primary_domain ⇒ String
The enterprise's primary domain, such as "example.com".
Corresponds to the JSON property primaryDomain
979 980 981 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 979 def primary_domain @primary_domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
986 987 988 989 990 991 992 993 994 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 986 def update!(**args) @administrator = args[:administrator] if args.key?(:administrator) @enterprise_type = args[:enterprise_type] if args.key?(:enterprise_type) @google_authentication_settings = args[:google_authentication_settings] if args.key?(:google_authentication_settings) @id = args[:id] if args.key?(:id) @managed_google_domain_type = args[:managed_google_domain_type] if args.key?(:managed_google_domain_type) @name = args[:name] if args.key?(:name) @primary_domain = args[:primary_domain] if args.key?(:primary_domain) end |