Class: Google::Apis::AndroidenterpriseV1::Enterprise

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

An Enterprises resource represents the binding between an EMM and a specific organization. That binding can be instantiated in one of two different ways using this API as follows: - For Google managed domain customers, the process involves using Enterprises.enroll and Enterprises.setAccount (in conjunction with artifacts obtained from the Admin console and the Google API Console) and submitted to the EMM through a more-or-less manual process. - For managed Google Play Accounts customers, the process involves using Enterprises. generateSignupUrl and Enterprises.completeSignup in conjunction with the managed Google Play sign-up UI (Google-provided mechanism) to create the binding without manual steps. As an EMM, you can support either or both approaches in your EMM console. See Create an Enterprise for details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enterprise

Returns a new instance of Enterprise.



980
981
982
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#administratorArray<Google::Apis::AndroidenterpriseV1::Administrator>

Admins of the enterprise. This is only supported for enterprises created via the EMM-initiated flow. Corresponds to the JSON property administrator



948
949
950
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 948

def administrator
  @administrator
end

#enterprise_typeString

The type of the enterprise. Corresponds to the JSON property enterpriseType

Returns:

  • (String)


953
954
955
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 953

def enterprise_type
  @enterprise_type
end

#google_authentication_settingsGoogle::Apis::AndroidenterpriseV1::GoogleAuthenticationSettings

Contains settings for Google-provided user authentication. Corresponds to the JSON property googleAuthenticationSettings



958
959
960
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 958

def google_authentication_settings
  @google_authentication_settings
end

#idString

The unique ID for the enterprise. Corresponds to the JSON property id

Returns:

  • (String)


963
964
965
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 963

def id
  @id
end

#managed_google_domain_typeString

The type of managed Google domain Corresponds to the JSON property managedGoogleDomainType

Returns:

  • (String)


968
969
970
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 968

def managed_google_domain_type
  @managed_google_domain_type
end

#nameString

The name of the enterprise, for example, "Example, Inc". Corresponds to the JSON property name

Returns:

  • (String)


973
974
975
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 973

def name
  @name
end

#primary_domainString

The enterprise's primary domain, such as "example.com". Corresponds to the JSON property primaryDomain

Returns:

  • (String)


978
979
980
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 978

def primary_domain
  @primary_domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



985
986
987
988
989
990
991
992
993
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 985

def update!(**args)
  @administrator = args[:administrator] if args.key?(:administrator)
  @enterprise_type = args[:enterprise_type] if args.key?(:enterprise_type)
  @google_authentication_settings = args[:google_authentication_settings] if args.key?(:google_authentication_settings)
  @id = args[:id] if args.key?(:id)
  @managed_google_domain_type = args[:managed_google_domain_type] if args.key?(:managed_google_domain_type)
  @name = args[:name] if args.key?(:name)
  @primary_domain = args[:primary_domain] if args.key?(:primary_domain)
end