Class: Google::Apis::AndroidenterpriseV1::GenerateProductApprovalUrlResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::GenerateProductApprovalUrlResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Instance Attribute Summary collapse
-
#url ⇒ String
A URL that can be rendered in an iframe to display the permissions (if any) of a product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateProductApprovalUrlResponse
constructor
A new instance of GenerateProductApprovalUrlResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateProductApprovalUrlResponse
Returns a new instance of GenerateProductApprovalUrlResponse.
2585 2586 2587 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2585 def initialize(**args) update!(**args) end |
Instance Attribute Details
#url ⇒ String
A URL that can be rendered in an iframe to display the permissions (if any) of
a product. This URL can be used to approve the product only once and only
within 24 hours of being generated, using the Products.approve call. If the
product is currently unapproved and has no permissions, this URL will point to
an empty page. If the product is currently approved, a URL will only be
generated if that product has added permissions since it was last approved,
and the URL will only display those new permissions that have not yet been
accepted.
Corresponds to the JSON property url
2583 2584 2585 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2583 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2590 2591 2592 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2590 def update!(**args) @url = args[:url] if args.key?(:url) end |