Class: Google::Apis::AndroidenterpriseV1::GroupLicense
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::GroupLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Deprecated: New integrations cannot use this method and can refer to our new recommendations
Instance Attribute Summary collapse
-
#acquisition_kind ⇒ String
How this group license was acquired.
-
#approval ⇒ String
Whether the product to which this group license relates is currently approved by the enterprise.
-
#num_provisioned ⇒ Fixnum
The total number of provisioned licenses for this product.
-
#num_purchased ⇒ Fixnum
The number of purchased licenses (possibly in multiple purchases).
-
#permissions ⇒ String
The permission approval status of the product.
-
#product_id ⇒ String
The ID of the product that the license is for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupLicense
constructor
A new instance of GroupLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupLicense
Returns a new instance of GroupLicense.
1250 1251 1252 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acquisition_kind ⇒ String
How this group license was acquired. "bulkPurchase" means that this
Grouplicenses resource was created because the enterprise purchased licenses
for this product; otherwise, the value is "free" (for free products).
Corresponds to the JSON property acquisitionKind
1206 1207 1208 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1206 def acquisition_kind @acquisition_kind end |
#approval ⇒ String
Whether the product to which this group license relates is currently approved
by the enterprise. Products are approved when a group license is first created,
but this approval may be revoked by an enterprise admin via Google Play.
Unapproved products will not be visible to end users in collections, and new
entitlements to them should not normally be created.
Corresponds to the JSON property approval
1215 1216 1217 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1215 def approval @approval end |
#num_provisioned ⇒ Fixnum
The total number of provisioned licenses for this product. Returned by read
operations, but ignored in write operations.
Corresponds to the JSON property numProvisioned
1221 1222 1223 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1221 def num_provisioned @num_provisioned end |
#num_purchased ⇒ Fixnum
The number of purchased licenses (possibly in multiple purchases). If this
field is omitted, then there is no limit on the number of licenses that can be
provisioned (for example, if the acquisition kind is "free").
Corresponds to the JSON property numPurchased
1228 1229 1230 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1228 def num_purchased @num_purchased end |
#permissions ⇒ String
The permission approval status of the product. This field is only set if the
product is approved. Possible states are: - "currentApproved", the current set
of permissions is approved, but additional permissions will require the
administrator to reapprove the product (If the product was approved without
specifying the approved permissions setting, then this is the default behavior.
), - "needsReapproval", the product has unapproved permissions. No additional
product licenses can be assigned until the product is reapproved, - "
allCurrentAndFutureApproved", the current permissions are approved and any
future permission updates will be automatically approved without administrator
review.
Corresponds to the JSON property permissions
1242 1243 1244 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1242 def @permissions end |
#product_id ⇒ String
The ID of the product that the license is for. For example, "app:com.google.
android.gm".
Corresponds to the JSON property productId
1248 1249 1250 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1248 def product_id @product_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1255 1256 1257 1258 1259 1260 1261 1262 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1255 def update!(**args) @acquisition_kind = args[:acquisition_kind] if args.key?(:acquisition_kind) @approval = args[:approval] if args.key?(:approval) @num_provisioned = args[:num_provisioned] if args.key?(:num_provisioned) @num_purchased = args[:num_purchased] if args.key?(:num_purchased) @permissions = args[:permissions] if args.key?(:permissions) @product_id = args[:product_id] if args.key?(:product_id) end |