Class: Google::Apis::AndroidenterpriseV1::KeyedAppState
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::KeyedAppState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Represents a keyed app state containing a key, timestamp, severity level, optional description, and optional data.
Instance Attribute Summary collapse
-
#data ⇒ String
Additional field intended for machine-readable data.
-
#key ⇒ String
Key indicating what the app is providing a state for.
-
#message ⇒ String
Free-form, human-readable message describing the app state.
-
#severity ⇒ String
Severity of the app state.
-
#state_timestamp_millis ⇒ Fixnum
Timestamp of when the app set the state in milliseconds since epoch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyedAppState
constructor
A new instance of KeyedAppState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyedAppState
Returns a new instance of KeyedAppState.
1455 1456 1457 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Additional field intended for machine-readable data. For example, a number or
JSON object. To prevent XSS, we recommend removing any HTML from the data
before displaying it.
Corresponds to the JSON property data
1428 1429 1430 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1428 def data @data end |
#key ⇒ String
Key indicating what the app is providing a state for. The content of the key
is set by the app's developer. To prevent XSS, we recommend removing any HTML
from the key before displaying it. This field will always be present.
Corresponds to the JSON property key
1435 1436 1437 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1435 def key @key end |
#message ⇒ String
Free-form, human-readable message describing the app state. For example, an
error message. To prevent XSS, we recommend removing any HTML from the message
before displaying it.
Corresponds to the JSON property message
1442 1443 1444 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1442 def @message end |
#severity ⇒ String
Severity of the app state. This field will always be present.
Corresponds to the JSON property severity
1447 1448 1449 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1447 def severity @severity end |
#state_timestamp_millis ⇒ Fixnum
Timestamp of when the app set the state in milliseconds since epoch. This
field will always be present.
Corresponds to the JSON property stateTimestampMillis
1453 1454 1455 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1453 def @state_timestamp_millis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1460 1461 1462 1463 1464 1465 1466 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1460 def update!(**args) @data = args[:data] if args.key?(:data) @key = args[:key] if args.key?(:key) @message = args[:message] if args.key?(:message) @severity = args[:severity] if args.key?(:severity) @state_timestamp_millis = args[:state_timestamp_millis] if args.key?(:state_timestamp_millis) end |