Class: Google::Apis::AndroidenterpriseV1::ManagedConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::ManagedConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Deprecated: New integrations cannot use this method and can refer to our new recommendations
Instance Attribute Summary collapse
-
#configuration_variables ⇒ Google::Apis::AndroidenterpriseV1::ConfigurationVariables
A configuration variables resource contains the managed configuration settings ID to be applied to a single user, as well as the variable set that is attributed to the user.
-
#kind ⇒ String
Deprecated.
-
#managed_property ⇒ Array<Google::Apis::AndroidenterpriseV1::ManagedProperty>
The set of managed properties for this configuration.
-
#product_id ⇒ String
The ID of the product that the managed configuration is for, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedConfiguration
constructor
A new instance of ManagedConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedConfiguration
Returns a new instance of ManagedConfiguration.
1546 1547 1548 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration_variables ⇒ Google::Apis::AndroidenterpriseV1::ConfigurationVariables
A configuration variables resource contains the managed configuration settings
ID to be applied to a single user, as well as the variable set that is
attributed to the user. The variable set will be used to replace placeholders
in the managed configuration settings.
Corresponds to the JSON property configurationVariables
1528 1529 1530 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1528 def configuration_variables @configuration_variables end |
#kind ⇒ String
Deprecated.
Corresponds to the JSON property kind
1533 1534 1535 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1533 def kind @kind end |
#managed_property ⇒ Array<Google::Apis::AndroidenterpriseV1::ManagedProperty>
The set of managed properties for this configuration.
Corresponds to the JSON property managedProperty
1538 1539 1540 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1538 def managed_property @managed_property end |
#product_id ⇒ String
The ID of the product that the managed configuration is for, e.g. "app:com.
google.android.gm".
Corresponds to the JSON property productId
1544 1545 1546 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1544 def product_id @product_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1551 1552 1553 1554 1555 1556 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1551 def update!(**args) @configuration_variables = args[:configuration_variables] if args.key?(:configuration_variables) @kind = args[:kind] if args.key?(:kind) @managed_property = args[:managed_property] if args.key?(:managed_property) @product_id = args[:product_id] if args.key?(:product_id) end |