Class: Google::Apis::AndroidenterpriseV1::NewPermissionsEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::NewPermissionsEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
An event generated when new permissions are added to an app.
Instance Attribute Summary collapse
-
#approved_permissions ⇒ Array<String>
The set of permissions that the enterprise admin has already approved for this application.
-
#product_id ⇒ String
The id of the product (e.g. "app:com.google.android.gm") for which new permissions were added.
-
#requested_permissions ⇒ Array<String>
The set of permissions that the app is currently requesting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NewPermissionsEvent
constructor
A new instance of NewPermissionsEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NewPermissionsEvent
Returns a new instance of NewPermissionsEvent.
1803 1804 1805 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approved_permissions ⇒ Array<String>
The set of permissions that the enterprise admin has already approved for this
application. Use Permissions.Get on the EMM API to retrieve details about
these permissions.
Corresponds to the JSON property approvedPermissions
1789 1790 1791 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1789 def @approved_permissions end |
#product_id ⇒ String
The id of the product (e.g. "app:com.google.android.gm") for which new
permissions were added. This field will always be present.
Corresponds to the JSON property productId
1795 1796 1797 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1795 def product_id @product_id end |
#requested_permissions ⇒ Array<String>
The set of permissions that the app is currently requesting. Use Permissions.
Get on the EMM API to retrieve details about these permissions.
Corresponds to the JSON property requestedPermissions
1801 1802 1803 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1801 def @requested_permissions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1808 1809 1810 1811 1812 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1808 def update!(**args) @approved_permissions = args[:approved_permissions] if args.key?(:approved_permissions) @product_id = args[:product_id] if args.key?(:product_id) @requested_permissions = args[:requested_permissions] if args.key?(:requested_permissions) end |