Class: Google::Apis::AndroidenterpriseV1::Notification
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::Notification
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A notification of one event relating to an enterprise.
Instance Attribute Summary collapse
-
#app_restrictions_schema_change_event ⇒ Google::Apis::AndroidenterpriseV1::AppRestrictionsSchemaChangeEvent
An event generated when a new app version is uploaded to Google Play and its app restrictions schema changed.
-
#app_update_event ⇒ Google::Apis::AndroidenterpriseV1::AppUpdateEvent
An event generated when a new version of an app is uploaded to Google Play.
-
#device_report_update_event ⇒ Google::Apis::AndroidenterpriseV1::DeviceReportUpdateEvent
An event generated when an updated device report is available.
-
#enterprise_id ⇒ String
The ID of the enterprise for which the notification is sent.
-
#enterprise_upgrade_event ⇒ Google::Apis::AndroidenterpriseV1::EnterpriseUpgradeEvent
An event generated when an enterprise is upgraded.
-
#install_failure_event ⇒ Google::Apis::AndroidenterpriseV1::InstallFailureEvent
An event generated when an app installation failed on a device Corresponds to the JSON property
installFailureEvent. -
#new_device_event ⇒ Google::Apis::AndroidenterpriseV1::NewDeviceEvent
An event generated when a new device is ready to be managed.
-
#new_permissions_event ⇒ Google::Apis::AndroidenterpriseV1::NewPermissionsEvent
An event generated when new permissions are added to an app.
-
#notification_type ⇒ String
Type of the notification.
-
#product_approval_event ⇒ Google::Apis::AndroidenterpriseV1::ProductApprovalEvent
An event generated when a product's approval status is changed.
-
#product_availability_change_event ⇒ Google::Apis::AndroidenterpriseV1::ProductAvailabilityChangeEvent
An event generated whenever a product's availability changes.
-
#timestamp_millis ⇒ Fixnum
The time when the notification was published in milliseconds since 1970-01- 01T00:00:00Z.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Notification
constructor
A new instance of Notification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Notification
Returns a new instance of Notification.
1886 1887 1888 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_restrictions_schema_change_event ⇒ Google::Apis::AndroidenterpriseV1::AppRestrictionsSchemaChangeEvent
An event generated when a new app version is uploaded to Google Play and its
app restrictions schema changed. To fetch the app restrictions schema for an
app, use Products.getAppRestrictionsSchema on the EMM API.
Corresponds to the JSON property appRestrictionsSchemaChangeEvent
1824 1825 1826 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1824 def app_restrictions_schema_change_event @app_restrictions_schema_change_event end |
#app_update_event ⇒ Google::Apis::AndroidenterpriseV1::AppUpdateEvent
An event generated when a new version of an app is uploaded to Google Play.
Notifications are sent for new public versions only: alpha, beta, or canary
versions do not generate this event. To fetch up-to-date version history for
an app, use Products.Get on the EMM API.
Corresponds to the JSON property appUpdateEvent
1832 1833 1834 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1832 def app_update_event @app_update_event end |
#device_report_update_event ⇒ Google::Apis::AndroidenterpriseV1::DeviceReportUpdateEvent
An event generated when an updated device report is available.
Corresponds to the JSON property deviceReportUpdateEvent
1837 1838 1839 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1837 def device_report_update_event @device_report_update_event end |
#enterprise_id ⇒ String
The ID of the enterprise for which the notification is sent. This will always
be present.
Corresponds to the JSON property enterpriseId
1843 1844 1845 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1843 def enterprise_id @enterprise_id end |
#enterprise_upgrade_event ⇒ Google::Apis::AndroidenterpriseV1::EnterpriseUpgradeEvent
An event generated when an enterprise is upgraded.
Corresponds to the JSON property enterpriseUpgradeEvent
1848 1849 1850 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1848 def enterprise_upgrade_event @enterprise_upgrade_event end |
#install_failure_event ⇒ Google::Apis::AndroidenterpriseV1::InstallFailureEvent
An event generated when an app installation failed on a device
Corresponds to the JSON property installFailureEvent
1853 1854 1855 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1853 def install_failure_event @install_failure_event end |
#new_device_event ⇒ Google::Apis::AndroidenterpriseV1::NewDeviceEvent
An event generated when a new device is ready to be managed.
Corresponds to the JSON property newDeviceEvent
1858 1859 1860 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1858 def new_device_event @new_device_event end |
#new_permissions_event ⇒ Google::Apis::AndroidenterpriseV1::NewPermissionsEvent
An event generated when new permissions are added to an app.
Corresponds to the JSON property newPermissionsEvent
1863 1864 1865 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1863 def @new_permissions_event end |
#notification_type ⇒ String
Type of the notification.
Corresponds to the JSON property notificationType
1868 1869 1870 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1868 def notification_type @notification_type end |
#product_approval_event ⇒ Google::Apis::AndroidenterpriseV1::ProductApprovalEvent
An event generated when a product's approval status is changed.
Corresponds to the JSON property productApprovalEvent
1873 1874 1875 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1873 def product_approval_event @product_approval_event end |
#product_availability_change_event ⇒ Google::Apis::AndroidenterpriseV1::ProductAvailabilityChangeEvent
An event generated whenever a product's availability changes.
Corresponds to the JSON property productAvailabilityChangeEvent
1878 1879 1880 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1878 def product_availability_change_event @product_availability_change_event end |
#timestamp_millis ⇒ Fixnum
The time when the notification was published in milliseconds since 1970-01-
01T00:00:00Z. This will always be present.
Corresponds to the JSON property timestampMillis
1884 1885 1886 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1884 def @timestamp_millis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1891 def update!(**args) @app_restrictions_schema_change_event = args[:app_restrictions_schema_change_event] if args.key?(:app_restrictions_schema_change_event) @app_update_event = args[:app_update_event] if args.key?(:app_update_event) @device_report_update_event = args[:device_report_update_event] if args.key?(:device_report_update_event) @enterprise_id = args[:enterprise_id] if args.key?(:enterprise_id) @enterprise_upgrade_event = args[:enterprise_upgrade_event] if args.key?(:enterprise_upgrade_event) @install_failure_event = args[:install_failure_event] if args.key?(:install_failure_event) @new_device_event = args[:new_device_event] if args.key?(:new_device_event) @new_permissions_event = args[:new_permissions_event] if args.key?(:new_permissions_event) @notification_type = args[:notification_type] if args.key?(:notification_type) @product_approval_event = args[:product_approval_event] if args.key?(:product_approval_event) @product_availability_change_event = args[:product_availability_change_event] if args.key?(:product_availability_change_event) @timestamp_millis = args[:timestamp_millis] if args.key?(:timestamp_millis) end |