Class: Google::Apis::AndroidenterpriseV1::NotificationSet
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::NotificationSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A resource returned by the PullNotificationSet API, which contains a collection of notifications for enterprises associated with the service account authenticated for the request.
Instance Attribute Summary collapse
-
#notification ⇒ Array<Google::Apis::AndroidenterpriseV1::Notification>
The notifications received, or empty if no notifications are present.
-
#notification_set_id ⇒ String
The notification set ID, required to mark the notification as received with the Enterprises.AcknowledgeNotification API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationSet
constructor
A new instance of NotificationSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationSet
Returns a new instance of NotificationSet.
1924 1925 1926 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#notification ⇒ Array<Google::Apis::AndroidenterpriseV1::Notification>
The notifications received, or empty if no notifications are present.
Corresponds to the JSON property notification
1915 1916 1917 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1915 def notification @notification end |
#notification_set_id ⇒ String
The notification set ID, required to mark the notification as received with
the Enterprises.AcknowledgeNotification API. This will be omitted if no
notifications are present.
Corresponds to the JSON property notificationSetId
1922 1923 1924 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1922 def notification_set_id @notification_set_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1929 1930 1931 1932 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1929 def update!(**args) @notification = args[:notification] if args.key?(:notification) @notification_set_id = args[:notification_set_id] if args.key?(:notification_set_id) end |