Class: Google::Apis::AndroidenterpriseV1::Permission
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::Permission
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A Permissions resource represents some extra capability, to be granted to an Android app, which requires explicit consent. An enterprise admin must consent to these permissions on behalf of their users before an entitlement for the app can be created. The permissions collection is read-only. The information provided for each permission (localized name and description) is intended to be used in the MDM user interface when obtaining consent from the enterprise.
Instance Attribute Summary collapse
-
#description ⇒ String
A longer description of the Permissions resource, giving more details of what it affects.
-
#name ⇒ String
The name of the permission.
-
#permission_id ⇒ String
An opaque string uniquely identifying the permission.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Permission
constructor
A new instance of Permission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Permission
Returns a new instance of Permission.
1995 1996 1997 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A longer description of the Permissions resource, giving more details of what
it affects.
Corresponds to the JSON property description
1983 1984 1985 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1983 def description @description end |
#name ⇒ String
The name of the permission.
Corresponds to the JSON property name
1988 1989 1990 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1988 def name @name end |
#permission_id ⇒ String
An opaque string uniquely identifying the permission.
Corresponds to the JSON property permissionId
1993 1994 1995 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 1993 def @permission_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2000 2001 2002 2003 2004 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2000 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @permission_id = args[:permission_id] if args.key?(:permission_id) end |