Class: Google::Apis::AndroidenterpriseV1::Product
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::Product
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A Products resource represents an app in the Google Play store that is available to at least some users in the enterprise. (Some apps are restricted to a single enterprise, and no information about them is made available outside that enterprise.) The information provided for each product (localized name, icon, link to the full Google Play details page) is intended to allow a basic representation of the product within an EMM user interface.
Instance Attribute Summary collapse
-
#app_restrictions_schema ⇒ Google::Apis::AndroidenterpriseV1::AppRestrictionsSchema
Represents the list of app restrictions available to be pre-configured for the product.
-
#app_tracks ⇒ Array<Google::Apis::AndroidenterpriseV1::TrackInfo>
The tracks visible to the enterprise.
-
#app_version ⇒ Array<Google::Apis::AndroidenterpriseV1::AppVersion>
App versions currently available for this product.
-
#author_name ⇒ String
The name of the author of the product (for example, the app developer).
-
#available_countries ⇒ Array<String>
The countries which this app is available in.
-
#available_tracks ⇒ Array<String>
Deprecated, use appTracks instead.
-
#category ⇒ String
The app category (e.g. RACING, SOCIAL, etc.) Corresponds to the JSON property
category. -
#content_rating ⇒ String
The content rating for this app.
-
#description ⇒ String
The localized promotional description, if available.
-
#details_url ⇒ String
A link to the (consumer) Google Play details page for the product.
-
#distribution_channel ⇒ String
How and to whom the package is made available.
-
#features ⇒ Array<String>
Noteworthy features (if any) of this product.
-
#full_description ⇒ String
The localized full app store description, if available.
-
#icon_url ⇒ String
A link to an image that can be used as an icon for the product.
-
#last_updated_timestamp_millis ⇒ Fixnum
The approximate time (within 7 days) the app was last published, expressed in milliseconds since epoch.
-
#min_android_sdk_version ⇒ Fixnum
The minimum Android SDK necessary to run the app.
-
#permissions ⇒ Array<Google::Apis::AndroidenterpriseV1::ProductPermission>
A list of permissions required by the app.
-
#product_id ⇒ String
A string of the form app:
. -
#product_pricing ⇒ String
Whether this product is free, free with in-app purchases, or paid.
-
#recent_changes ⇒ String
A description of the recent changes made to the app.
-
#requires_container_app ⇒ Boolean
(also: #requires_container_app?)
Deprecated.
-
#screenshot_urls ⇒ Array<String>
A list of screenshot links representing the app.
-
#signing_certificate ⇒ Google::Apis::AndroidenterpriseV1::ProductSigningCertificate
The certificate used to sign this product.
-
#small_icon_url ⇒ String
A link to a smaller image that can be used as an icon for the product.
-
#title ⇒ String
The name of the product.
-
#work_details_url ⇒ String
A link to the managed Google Play details page for the product, for use by an Enterprise admin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Product
constructor
A new instance of Product.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Product
Returns a new instance of Product.
2228 2229 2230 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_restrictions_schema ⇒ Google::Apis::AndroidenterpriseV1::AppRestrictionsSchema
Represents the list of app restrictions available to be pre-configured for the
product.
Corresponds to the JSON property appRestrictionsSchema
2088 2089 2090 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2088 def app_restrictions_schema @app_restrictions_schema end |
#app_tracks ⇒ Array<Google::Apis::AndroidenterpriseV1::TrackInfo>
The tracks visible to the enterprise.
Corresponds to the JSON property appTracks
2093 2094 2095 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2093 def app_tracks @app_tracks end |
#app_version ⇒ Array<Google::Apis::AndroidenterpriseV1::AppVersion>
App versions currently available for this product.
Corresponds to the JSON property appVersion
2098 2099 2100 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2098 def app_version @app_version end |
#author_name ⇒ String
The name of the author of the product (for example, the app developer).
Corresponds to the JSON property authorName
2103 2104 2105 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2103 def @author_name end |
#available_countries ⇒ Array<String>
The countries which this app is available in.
Corresponds to the JSON property availableCountries
2108 2109 2110 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2108 def available_countries @available_countries end |
#available_tracks ⇒ Array<String>
Deprecated, use appTracks instead.
Corresponds to the JSON property availableTracks
2113 2114 2115 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2113 def available_tracks @available_tracks end |
#category ⇒ String
The app category (e.g. RACING, SOCIAL, etc.)
Corresponds to the JSON property category
2118 2119 2120 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2118 def category @category end |
#content_rating ⇒ String
The content rating for this app.
Corresponds to the JSON property contentRating
2123 2124 2125 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2123 def @content_rating end |
#description ⇒ String
The localized promotional description, if available.
Corresponds to the JSON property description
2128 2129 2130 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2128 def description @description end |
#details_url ⇒ String
A link to the (consumer) Google Play details page for the product.
Corresponds to the JSON property detailsUrl
2133 2134 2135 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2133 def details_url @details_url end |
#distribution_channel ⇒ String
How and to whom the package is made available. The value publicGoogleHosted
means that the package is available through the Play store and not restricted
to a specific enterprise. The value privateGoogleHosted means that the package
is a private app (restricted to an enterprise) but hosted by Google. The value
privateSelfHosted means that the package is a private app (restricted to an
enterprise) and is privately hosted.
Corresponds to the JSON property distributionChannel
2143 2144 2145 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2143 def distribution_channel @distribution_channel end |
#features ⇒ Array<String>
Noteworthy features (if any) of this product.
Corresponds to the JSON property features
2148 2149 2150 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2148 def features @features end |
#full_description ⇒ String
The localized full app store description, if available.
Corresponds to the JSON property fullDescription
2153 2154 2155 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2153 def full_description @full_description end |
#icon_url ⇒ String
A link to an image that can be used as an icon for the product. This image is
suitable for use at up to 512px x 512px.
Corresponds to the JSON property iconUrl
2159 2160 2161 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2159 def icon_url @icon_url end |
#last_updated_timestamp_millis ⇒ Fixnum
The approximate time (within 7 days) the app was last published, expressed in
milliseconds since epoch.
Corresponds to the JSON property lastUpdatedTimestampMillis
2165 2166 2167 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2165 def @last_updated_timestamp_millis end |
#min_android_sdk_version ⇒ Fixnum
The minimum Android SDK necessary to run the app.
Corresponds to the JSON property minAndroidSdkVersion
2170 2171 2172 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2170 def min_android_sdk_version @min_android_sdk_version end |
#permissions ⇒ Array<Google::Apis::AndroidenterpriseV1::ProductPermission>
A list of permissions required by the app.
Corresponds to the JSON property permissions
2175 2176 2177 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2175 def @permissions end |
#product_id ⇒ String
A string of the form app:productId
2181 2182 2183 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2181 def product_id @product_id end |
#product_pricing ⇒ String
Whether this product is free, free with in-app purchases, or paid. If the
pricing is unknown, this means the product is not generally available anymore (
even though it might still be available to people who own it).
Corresponds to the JSON property productPricing
2188 2189 2190 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2188 def product_pricing @product_pricing end |
#recent_changes ⇒ String
A description of the recent changes made to the app.
Corresponds to the JSON property recentChanges
2193 2194 2195 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2193 def recent_changes @recent_changes end |
#requires_container_app ⇒ Boolean Also known as: requires_container_app?
Deprecated.
Corresponds to the JSON property requiresContainerApp
2198 2199 2200 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2198 def requires_container_app @requires_container_app end |
#screenshot_urls ⇒ Array<String>
A list of screenshot links representing the app.
Corresponds to the JSON property screenshotUrls
2204 2205 2206 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2204 def screenshot_urls @screenshot_urls end |
#signing_certificate ⇒ Google::Apis::AndroidenterpriseV1::ProductSigningCertificate
The certificate used to sign this product.
Corresponds to the JSON property signingCertificate
2209 2210 2211 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2209 def signing_certificate @signing_certificate end |
#small_icon_url ⇒ String
A link to a smaller image that can be used as an icon for the product. This
image is suitable for use at up to 128px x 128px.
Corresponds to the JSON property smallIconUrl
2215 2216 2217 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2215 def small_icon_url @small_icon_url end |
#title ⇒ String
The name of the product.
Corresponds to the JSON property title
2220 2221 2222 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2220 def title @title end |
#work_details_url ⇒ String
A link to the managed Google Play details page for the product, for use by an
Enterprise admin.
Corresponds to the JSON property workDetailsUrl
2226 2227 2228 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2226 def work_details_url @work_details_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2233 def update!(**args) @app_restrictions_schema = args[:app_restrictions_schema] if args.key?(:app_restrictions_schema) @app_tracks = args[:app_tracks] if args.key?(:app_tracks) @app_version = args[:app_version] if args.key?(:app_version) @author_name = args[:author_name] if args.key?(:author_name) @available_countries = args[:available_countries] if args.key?(:available_countries) @available_tracks = args[:available_tracks] if args.key?(:available_tracks) @category = args[:category] if args.key?(:category) @content_rating = args[:content_rating] if args.key?(:content_rating) @description = args[:description] if args.key?(:description) @details_url = args[:details_url] if args.key?(:details_url) @distribution_channel = args[:distribution_channel] if args.key?(:distribution_channel) @features = args[:features] if args.key?(:features) @full_description = args[:full_description] if args.key?(:full_description) @icon_url = args[:icon_url] if args.key?(:icon_url) @last_updated_timestamp_millis = args[:last_updated_timestamp_millis] if args.key?(:last_updated_timestamp_millis) @min_android_sdk_version = args[:min_android_sdk_version] if args.key?(:min_android_sdk_version) @permissions = args[:permissions] if args.key?(:permissions) @product_id = args[:product_id] if args.key?(:product_id) @product_pricing = args[:product_pricing] if args.key?(:product_pricing) @recent_changes = args[:recent_changes] if args.key?(:recent_changes) @requires_container_app = args[:requires_container_app] if args.key?(:requires_container_app) @screenshot_urls = args[:screenshot_urls] if args.key?(:screenshot_urls) @signing_certificate = args[:signing_certificate] if args.key?(:signing_certificate) @small_icon_url = args[:small_icon_url] if args.key?(:small_icon_url) @title = args[:title] if args.key?(:title) @work_details_url = args[:work_details_url] if args.key?(:work_details_url) end |