Class: Google::Apis::AndroidenterpriseV1::ProductPermission
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::ProductPermission
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A product permissions resource represents the set of permissions required by a specific app and whether or not they have been accepted by an enterprise admin. The API can be used to read the set of permissions, and also to update the set to indicate that permissions have been accepted.
Instance Attribute Summary collapse
-
#permission_id ⇒ String
An opaque string uniquely identifying the permission.
-
#state ⇒ String
Whether the permission has been accepted or not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductPermission
constructor
A new instance of ProductPermission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductPermission
Returns a new instance of ProductPermission.
2332 2333 2334 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#permission_id ⇒ String
An opaque string uniquely identifying the permission.
Corresponds to the JSON property permissionId
2325 2326 2327 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2325 def @permission_id end |
#state ⇒ String
Whether the permission has been accepted or not.
Corresponds to the JSON property state
2330 2331 2332 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2330 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2337 2338 2339 2340 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2337 def update!(**args) @permission_id = args[:permission_id] if args.key?(:permission_id) @state = args[:state] if args.key?(:state) end |