Class: Google::Apis::AndroidenterpriseV1::ProductsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::ProductsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Instance Attribute Summary collapse
-
#page_info ⇒ Google::Apis::AndroidenterpriseV1::PageInfo
Information about the current page.
-
#product ⇒ Array<Google::Apis::AndroidenterpriseV1::Product>
Information about a product (e.g. an app) in the Google Play store, for display to an enterprise admin.
-
#token_pagination ⇒ Google::Apis::AndroidenterpriseV1::TokenPagination
Pagination information returned by a List operation when token pagination is enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductsListResponse
constructor
A new instance of ProductsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductsListResponse
Returns a new instance of ProductsListResponse.
2624 2625 2626 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_info ⇒ Google::Apis::AndroidenterpriseV1::PageInfo
Information about the current page. List operations that supports paging
return only one "page" of results. This protocol buffer message describes the
page that has been returned.
Corresponds to the JSON property pageInfo
2604 2605 2606 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2604 def page_info @page_info end |
#product ⇒ Array<Google::Apis::AndroidenterpriseV1::Product>
Information about a product (e.g. an app) in the Google Play store, for
display to an enterprise admin.
Corresponds to the JSON property product
2610 2611 2612 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2610 def product @product end |
#token_pagination ⇒ Google::Apis::AndroidenterpriseV1::TokenPagination
Pagination information returned by a List operation when token pagination is
enabled. List operations that supports paging return only one "page" of
results. This protocol buffer message describes the page that has been
returned. When using token pagination, clients should use the next/previous
token to get another page of the result. The presence or absence of next/
previous token indicates whether a next/previous page is available and
provides a mean of accessing this page. ListRequest.page_token should be set
to either next_page_token or previous_page_token to access another page.
Corresponds to the JSON property tokenPagination
2622 2623 2624 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2622 def token_pagination @token_pagination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2629 2630 2631 2632 2633 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2629 def update!(**args) @page_info = args[:page_info] if args.key?(:page_info) @product = args[:product] if args.key?(:product) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) end |