Class: Google::Apis::AndroidenterpriseV1::ServiceAccount
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::ServiceAccount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
A service account identity, including the name and credentials that can be used to authenticate as the service account.
Instance Attribute Summary collapse
-
#key ⇒ Google::Apis::AndroidenterpriseV1::ServiceAccountKey
Deprecated: New integrations cannot use this method and can refer to our new recommendations Corresponds to the JSON property
key. -
#name ⇒ String
The account name of the service account, in the form of an email address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAccount
constructor
A new instance of ServiceAccount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAccount
Returns a new instance of ServiceAccount.
2653 2654 2655 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ Google::Apis::AndroidenterpriseV1::ServiceAccountKey
Deprecated: New integrations cannot use this method and can refer to our
new recommendations
Corresponds to the JSON property key
2645 2646 2647 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2645 def key @key end |
#name ⇒ String
The account name of the service account, in the form of an email address.
Assigned by the server.
Corresponds to the JSON property name
2651 2652 2653 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2651 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2658 2659 2660 2661 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2658 def update!(**args) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) end |