Class: Google::Apis::AndroidenterpriseV1::ServiceAccountKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

Deprecated: New integrations cannot use this method and can refer to our new recommendations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAccountKey

Returns a new instance of ServiceAccountKey.



2695
2696
2697
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

The body of the private key credentials file, in string format. This is only populated when the ServiceAccountKey is created, and is not stored by Google. When type is "pkcs12", the contents of the data field is base64 encoded and has the password "notasecret". Corresponds to the JSON property data

Returns:

  • (String)


2675
2676
2677
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2675

def data
  @data
end

#idString

An opaque, unique identifier for this ServiceAccountKey. Assigned by the server. Corresponds to the JSON property id

Returns:

  • (String)


2681
2682
2683
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2681

def id
  @id
end

#public_dataString

Public key data for the credentials file. This is an X.509 cert. If you are using the googleCredentials key type, this is identical to the cert that can be retrieved by using the X.509 cert url inside of the credentials file. Corresponds to the JSON property publicData

Returns:

  • (String)


2688
2689
2690
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2688

def public_data
  @public_data
end

#typeString

The file format of the generated key data. Corresponds to the JSON property type

Returns:

  • (String)


2693
2694
2695
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2693

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2700
2701
2702
2703
2704
2705
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2700

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @id = args[:id] if args.key?(:id)
  @public_data = args[:public_data] if args.key?(:public_data)
  @type = args[:type] if args.key?(:type)
end