Class: Google::Apis::AndroidenterpriseV1::StoreCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

Definition of a managed Google Play store cluster, a list of products displayed as part of a store page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoreCluster

Returns a new instance of StoreCluster.



2794
2795
2796
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2794

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique ID of this cluster. Assigned by the server. Immutable once assigned. Corresponds to the JSON property id

Returns:

  • (String)


2769
2770
2771
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2769

def id
  @id
end

#nameArray<Google::Apis::AndroidenterpriseV1::LocalizedText>

Ordered list of localized strings giving the name of this page. The text displayed is the one that best matches the user locale, or the first entry if there is no good match. There needs to be at least one entry. Corresponds to the JSON property name



2776
2777
2778
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2776

def name
  @name
end

#order_in_pageString

String (US-ASCII only) used to determine order of this cluster within the parent page's elements. Page elements are sorted in lexicographic order of this field. Duplicated values are allowed, but ordering between elements with duplicate order is undefined. The value of this field is never visible to a user, it is used solely for the purpose of defining an ordering. Maximum length is 256 characters. Corresponds to the JSON property orderInPage

Returns:

  • (String)


2786
2787
2788
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2786

def order_in_page
  @order_in_page
end

#product_idArray<String>

List of products in the order they are displayed in the cluster. There should not be duplicates within a cluster. Corresponds to the JSON property productId

Returns:

  • (Array<String>)


2792
2793
2794
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2792

def product_id
  @product_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2799
2800
2801
2802
2803
2804
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2799

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @order_in_page = args[:order_in_page] if args.key?(:order_in_page)
  @product_id = args[:product_id] if args.key?(:product_id)
end