Class: Google::Apis::AndroidenterpriseV1::StoreLayout
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::StoreLayout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
General setting for the managed Google Play store layout, currently only specifying the page to display the first time the store is opened.
Instance Attribute Summary collapse
-
#homepage_id ⇒ String
The ID of the store page to be used as the homepage.
-
#store_layout_type ⇒ String
The store layout type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoreLayout
constructor
A new instance of StoreLayout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoreLayout
Returns a new instance of StoreLayout.
2827 2828 2829 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#homepage_id ⇒ String
The ID of the store page to be used as the homepage. The homepage is the first
page shown in the managed Google Play Store. Not specifying a homepage is
equivalent to setting the store layout type to "basic".
Corresponds to the JSON property homepageId
2817 2818 2819 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2817 def homepage_id @homepage_id end |
#store_layout_type ⇒ String
The store layout type. By default, this value is set to "basic" if the
homepageId field is not set, and to "custom" otherwise. If set to "basic", the
layout will consist of all approved apps that have been whitelisted for the
user.
Corresponds to the JSON property storeLayoutType
2825 2826 2827 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2825 def store_layout_type @store_layout_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2832 2833 2834 2835 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2832 def update!(**args) @homepage_id = args[:homepage_id] if args.key?(:homepage_id) @store_layout_type = args[:store_layout_type] if args.key?(:store_layout_type) end |