Class: Google::Apis::AndroidenterpriseV1::StorePage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

Definition of a managed Google Play store page, made of a localized name and links to other pages. A page also contains clusters defined as a subcollection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorePage

Returns a new instance of StorePage.



2902
2903
2904
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique ID of this page. Assigned by the server. Immutable once assigned. Corresponds to the JSON property id

Returns:

  • (String)


2885
2886
2887
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2885

def id
  @id
end

Ordered list of pages a user should be able to reach from this page. The list can't include this page. It is recommended that the basic pages are created first, before adding the links between pages. The API doesn't verify that the pages exist or the pages are reachable. Corresponds to the JSON property link

Returns:

  • (Array<String>)


2893
2894
2895
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2893

def link
  @link
end

#nameArray<Google::Apis::AndroidenterpriseV1::LocalizedText>

Ordered list of localized strings giving the name of this page. The text displayed is the one that best matches the user locale, or the first entry if there is no good match. There needs to be at least one entry. Corresponds to the JSON property name



2900
2901
2902
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2900

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2907
2908
2909
2910
2911
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2907

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @link = args[:link] if args.key?(:link)
  @name = args[:name] if args.key?(:name)
end