Class: Google::Apis::AndroidenterpriseV1::TrackInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb

Overview

Id to name association of a track.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackInfo

Returns a new instance of TrackInfo.



2964
2965
2966
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#track_aliasString

A modifiable name for a track. This is the visible name in the play developer console. Corresponds to the JSON property trackAlias

Returns:

  • (String)


2955
2956
2957
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2955

def track_alias
  @track_alias
end

#track_idString

Unmodifiable, unique track identifier. This identifier is the releaseTrackId in the url of the play developer console page that displays the track information. Corresponds to the JSON property trackId

Returns:

  • (String)


2962
2963
2964
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2962

def track_id
  @track_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2969
2970
2971
2972
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2969

def update!(**args)
  @track_alias = args[:track_alias] if args.key?(:track_alias)
  @track_id = args[:track_id] if args.key?(:track_id)
end