Class: Google::Apis::AndroidenterpriseV1::TrackInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidenterpriseV1::TrackInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidenterprise_v1/classes.rb,
lib/google/apis/androidenterprise_v1/representations.rb,
lib/google/apis/androidenterprise_v1/representations.rb
Overview
Id to name association of a track.
Instance Attribute Summary collapse
-
#track_alias ⇒ String
A modifiable name for a track.
-
#track_id ⇒ String
Unmodifiable, unique track identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrackInfo
constructor
A new instance of TrackInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrackInfo
Returns a new instance of TrackInfo.
2963 2964 2965 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#track_alias ⇒ String
A modifiable name for a track. This is the visible name in the play developer
console.
Corresponds to the JSON property trackAlias
2954 2955 2956 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2954 def track_alias @track_alias end |
#track_id ⇒ String
Unmodifiable, unique track identifier. This identifier is the releaseTrackId
in the url of the play developer console page that displays the track
information.
Corresponds to the JSON property trackId
2961 2962 2963 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2961 def track_id @track_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2968 2969 2970 2971 |
# File 'lib/google/apis/androidenterprise_v1/classes.rb', line 2968 def update!(**args) @track_alias = args[:track_alias] if args.key?(:track_alias) @track_id = args[:track_id] if args.key?(:track_id) end |